Refactoring. Point objects are now plain arrayrefs. Slicing is 30% faster.

This commit is contained in:
Alessandro Ranellucci committed 2011-10-12 14:54:49 +02:00
1 parent 774717c8bb
commit e410410dc7
10 files changed
+44 -55

No files matched your search

+1 -1
View File
@@ -9,7 +9,7 @@ sub split_at {
my $self = shift;
my ($point) = @_;
$point = Slic3r::Point->cast($point);
$point = Slic3r::Point->new($point);
# find index of point
my $i = -1;